# -*- coding: utf-8 -*-

import locale
import logging
from pysimplesoap.client import SoapClient
from django.conf import settings
import datetime

import acomea.soap2.utils.soap as utils


log = logging.getLogger("acomea.soap")


class MyAcomeaSoapClient:

    def __init__(self):
        log.debug("AcomeaClientRiservataCms init")
        if not settings.SOAP_RESERVED_URL:
            return
        try:
            self.client = SoapClient(wsdl=settings.SOAP_RESERVED_URL, trace=False)
        except Exception, exc:
            log.warning("AcomeaClientRiservataCms Exception %s" % str(exc))
            raise

    def get_DataGiro(self):
        return self.client.DataGiro()['DataGiroResult'].date()

    def get_DataValo(self):
        return self.client.DataValo()['DataValoResult'].date()

    def get_cliente(self, cod_fiscale):
        cod_fiscale = cod_fiscale.upper()
        cliente = self.client.AR_GetCliente(cod_fiscale)['ClienteNEW']
        output = utils.format_get_cliente(cliente)
        return output

    def get_AR_Riepilogo(self, prodotto, partecipazione, cod_fiscale, rapporto=0):
        prodotto = prodotto.upper()
        partecipazione = partecipazione.upper()
        riepilogo = self.client.AR_Riepilogo(
            prodotto, partecipazione, cod_fiscale, rapporto
        )['AR_RiepilogoResult']
        output = utils.format_ar_riepilogo(riepilogo)
        return output

    def get_AR_SintesiRapporti(self, prodotto, partecipazione, cod_fiscale, rapporto=0):
        prodotto = prodotto.upper()
        partecipazione = partecipazione.upper()
        dettaglio = self.client.AR_SintesiRapporti(
            prodotto, partecipazione, cod_fiscale, rapporto
        )['AR_SintesiRapportiResult']
        output = utils.format_ar_sintesirapporti(dettaglio)
        return output

    def get_AR_DEPFON(self, rapporto, deposito, fondo, tc):
        dettaglio = self.client.AR_DEPFON(
            rapporto, deposito, fondo, tc
        )['AR_DEPFONResult']
        output = utils.format_ar_depfon(dettaglio)
        return output

    def get_AR_Ripartizione(self, prodotto, partecipazione, cod_fiscale, rapporto=0):
        prodotto = prodotto.upper()
        partecipazione = partecipazione.upper()
        riepilogo = self.client.AR_Ripartizione(
            prodotto, partecipazione, cod_fiscale, rapporto
        )['AR_RipartizioneResult']
        output = utils.format_ar_ripartizione(riepilogo)
        return output

    def get_AR_PosizioneStorica(self, prodotto, partecipazione, cod_fiscale, data, rapporto=0):
        prodotto = prodotto.upper()
        partecipazione = partecipazione.upper()
        riepilogo = self.client.AR_PosizioneStorica(
            prodotto, partecipazione, cod_fiscale, data, rapporto
        )['AR_PosizioneStoricaResult']
        output = utils.format_ar_posizione_storica(riepilogo)
        return output

    def get_AR_Confronto(self, partecipazione, cod_fiscale, data_dal, data_al, rapporto=0):
        partecipazione = partecipazione.upper()
        confronto = self.client.AR_Confronto(
            partecipazione, cod_fiscale, data_dal, data_al, rapporto
        )['AR_ConfrontoResult']
        output = utils.format_ar_confronto(confronto)
        return output

    def get_AR_MovimentiFC(self, partecipazione, cod_fiscale, date_begin=None, date_end=None, rapporto=0):
        partecipazione = partecipazione.upper()
        date_begin = datetime.date(1970, 1, 1) if date_begin is None else date_begin
        date_end = datetime.date.today() if date_end is None else date_end
        operazioni = self.client.AR_MovimentiFC(
            cod_fiscale, partecipazione, date_begin, date_end, rapporto
        )['AR_MovimentiFCResult']
        output = utils.format_ar_movimenti_fc(operazioni)
        return output

    def get_AR_MovimentiGI(self, partecipazione, cod_fiscale, date_begin=None, date_end=None, rapporto=0):
        partecipazione = partecipazione.upper()
        date_begin = datetime.date(1970, 1, 1) if date_begin is None else date_begin
        date_end = datetime.date.today() if date_end is None else date_end
        operazioni = self.client.AR_MovimentiGI(
            cod_fiscale, partecipazione, date_begin, date_end, rapporto
        )['AR_MovimentiGIResult']
        output = utils.format_ar_movimenti_gi(operazioni)
        return output

    def get_AR_MovimentoDett(self, progr_caricamento, progr_rec_aggancio):
        movimento = self.client.AR_GetMovimentoDett(progr_caricamento, progr_rec_aggancio)['AR_GetMovimentoDettResult']
        output = utils.format_ar_movimento_dett(movimento)
        return output

    def get_AR_Riclassificazione_GI(self, partecipazione, cod_fiscale, rapporto=0):
        soap_key = 'AR_Riclassificazione_GIResult'
        riclassificazione = self.client.AR_Riclassificazione_GI(partecipazione, cod_fiscale, rapporto)[soap_key]
        output = utils.format_ar_riclassificazione_gi(riclassificazione, partecipazione)
        return output

    def get_AR_Titoli_GI(self, partecipazione, cod_fiscale, rapporto=0):
        titoli = self.client.AR_Titoli_GI(partecipazione, cod_fiscale, rapporto)['AR_Titoli_GIResult']
        output = utils.format_ar_titoli_gi(titoli)
        return output

    def get_AR_TitoliDettPrz_GI(self, codice_titolo, rapporto=0):
        dataset = self.client.AR_TitoliDettPrz_GI(codice_titolo, rapporto)['AR_TitoliDettPrz_GIResult']
        output = utils.format_ar_titolidettprz_gi(dataset)
        return output

    def get_operazioni_in_corso_web(self, cod_fiscale):
        cod_fiscale = cod_fiscale.upper()
        operazioni = self.client.OpOnline_GetOpInCorsoWEB(cod_fiscale)['OpOnline_GetOpInCorsoWEBResult']
        output = utils.format_operazioni_in_corso_web(operazioni)
        return output

    def get_operazioni_in_corso_contra(self, cod_fiscale):
        cod_fiscale = cod_fiscale.upper()
        operazioni = self.client.OpOnline_GetOpInCorsoCONTRA(cod_fiscale)['OpOnline_GetOpInCorsoCONTRAResult']
        output = utils.format_operazioni_in_corso_contra(operazioni)
        return output

    def annulla_operazione_in_corso_web(self, numero_operazione, cod_fiscale):
        cod_fiscale = cod_fiscale.upper()
        output = self.client.AnnullaOperazioneWEB(numero_operazione, cod_fiscale)['AnnullaOperazioneWEBResult']
        return output

    def get_servizi_in_corso_web(self, cod_fiscale):
        cod_fiscale = cod_fiscale.upper()
        servizi = self.client.OpServizi_GetServiziInCorsoWEB(cod_fiscale)['OpServizi_GetServiziInCorsoWEBResult']
        output = utils.format_servizi_in_corso_web(servizi)
        return output

    def get_servizi_attivi(self, cod_fiscale):
        cod_fiscale = cod_fiscale.upper()
        servizi = self.client.OpServizi_GetServiziAttivi(cod_fiscale)['OpServizi_GetServiziAttiviResult']
        output = utils.format_servizi_attivi(servizi)
        return output

    def annulla_servizio_web(self, numero_operazione, cod_fiscale):
        cod_fiscale = cod_fiscale.upper()
        output = self.client.AnnullaServizioWEB(numero_operazione, cod_fiscale)['AnnullaServizioWEBResult']
        return output

    def revoca_servizio_attivo(self, numero_operazione, cod_fiscale, simulazione, tipo_servizio):
        cod_fiscale = cod_fiscale.upper()
        output = self.client.OpServizi_ADDRevoca1(
            cod_fiscale, simulazione, tipo_servizio, numero_operazione
        )['OpServizi_ADDRevoca1Result']
        return output
