# -*- coding: utf-8 -*-

import calendar
import datetime
import simplejson


def get_ar_depfon_chart_dataset(dati):
    data = [[calendar.timegm(dato['data'].utctimetuple())*1000.0, dato['val']] for dato in dati]
    chart_options = {
        'chart': {
            'renderTo': 'dettaglio-modale-chart',
            'type': 'line',
            'zoomType': 'x',
        },
        'credits': {
            'text': '',
            'enabled': 'false'
        },
        'title': {
            'text': None,
        },
        'subtitle': {
            'text': None
        },
        'xAxis': {
            'id': 'x-axis',
            'type': 'datetime',
            'labels': {
                'enabled': False
            },
            'title': {
                'text': None
            },
            'dateTimeLabelFormats': {
                'month': '%b \'%y',
            },
            'tickInterval': 30,
        },
        'yAxis': {
            'title': {
                'text': 'Valore',
            },
            'min':None,
            'max':None
        },
        'tooltip': {
            'crosshairs': True,
            'shared': True
        },
        'legend': {
            'enabled': False,
        },
        'plotOptions': {
            'line': {
                'lineWidth': 1,
                'marker': {
                    'enabled': False
                },
                'shadow': False,
                'turboThreshold': 10000,
            }
        },
        'series': [{
            'name': 'Valore Fondo',
            'data': data,
            'color': '#3E576F'
        }],
    }
    return simplejson.dumps(chart_options)


def get_riclassificazione_portafogli_pie_dataset(dati, partecipazione, nome):
    data = [{'name': data['descrizione'], 'y': data['peso'], 'color': data['rgb']} for data in dati]
    chart_options = {
        'credits': {
            'text': '',
            'enabled': 'false'
        },
        'chart': {
            'margin': [0, 0, 0, 0],
            'spacingTop': 0,
            'spacingBottom': 0,
            'spacingLeft': 0,
            'spacingRight': 0,
            'renderTo': "riclassificazione-portafogli-pie-{}-{}".format(partecipazione, nome),
            'type': 'pie',
        },
        'plotOptions': {
            'pie': {
                'size': '100%',
                'dataLabels': {
                    'enabled': False
                },
                'enableMouseTracking': False,
            },
        },
        'title': {
            'text': None
        },
        'subtitle': {
            'text': None
        },
        'series': [{
            'name': 'fondo',
            'data': data,
        }]
    }
    return simplejson.dumps(chart_options)


def get_titolidettprz_gi_chart_dataset(dati):
    data = [[calendar.timegm(dato['data'].utctimetuple())*1000.0, dato['prezzo']] for dato in dati]
    chart_options = {
        'credits': {
            'text': '',
            'enabled': 'false'
        },
        'chart': {
            'zoomType': 'x',
            'renderTo': "dettaglio-titoli-modale-chart",
        },
        'title': {
            'text': None,
        },
        'xAxis': {
            'type': 'datetime',
            'minPadding': 0.025,
            'maxPadding': 0.025,
        },
        'yAxis': {
            'title': {
                'text': 'Prezzo',
            }
        },
        'legend': {
            'enabled': False,
        },
        'plotOptions': {
            'area': {
                'fillColor': {
                   'linearGradient': {
                       'x1': 0, 'y1': 0, 'x2': 0, 'y2': 1
                   },
                   'stops': [
                       [0, '#2f7ed8'],
                       [1, '#fff']
                   ]
                },
                'marker': {
                    'radius': 1
                },
                'lineWidth': 1,
                'states': {
                    'hover': {
                        'lineWidth': 1
                    }
                },
                'threshold': None,
            },
        },
        'series': [{
            'type': 'area',
            'name': 'Prezzo',
            'data': data
        }],
    }
    return simplejson.dumps(chart_options)
