# -*- coding: utf-8 -*-

import datetime
import locale
import random

import acomea.soap2.utils.highcharts as highcharts


def format_get_cliente(cliente):

    def has_product(cliente, tipo_prodotto, partecipazione):
        for prodotto in cliente['prodotti']:
            if prodotto['tipo_prodotto'] == tipo_prodotto:
                return bool(len([
                        rapporto for rapporto in prodotto['rapporti'] if rapporto['ruolo'].lower() == partecipazione
                ]))
        return False

    def get_product_posizione_rapporti(cliente, tipo_prodotto, partecipazione):
        for prodotto in cliente['prodotti']:
            if prodotto['tipo_prodotto'] == tipo_prodotto:
                rapporti = prodotto['rapporti']
                return [
                    rapporto['codice_rapporto'] for rapporto in rapporti if rapporto['ruolo'].lower() == partecipazione
                    ]
        return []

    def get_product_posizione_contratti(cliente, tipo_prodotto, partecipazione):
        output = []
        for prodotto in cliente['prodotti']:
            if prodotto['tipo_prodotto'] == tipo_prodotto:
                rapporti = prodotto['rapporti']
                for rapporto in rapporti:
                    if rapporto['ruolo'].lower() == partecipazione:
                        contratti = rapporto['contratti']
                        for contratto in contratti:
                            if contratto['numero_contratto'] not in output:
                                output.append(contratto['numero_contratto'])
        return output

    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = {
        'codice_fiscale': cliente['CODFISC'],
        'nome': cliente['Nome'],
        'cognome': cliente['Cognome'],
        'email': cliente['Mail'],
        'tipo_partecipante': cliente['TipoPartecipante'],
        'is_dead': cliente['IsDead'],
        'is_intestatario': cliente['IsIntestatario'],
        'is_cointestatario': cliente['IsCoIntestatario'],
        'is_found': cliente['Found'],
        'is_persona_fisica': cliente['IsPF'],
        'data_nascita': datetime.datetime.strptime(
            cliente['DtNasc'], "%d/%m/%Y %H:%M:%S"
        ).date() if cliente['DtNasc'] else None,
        'codice_cliente_fondi': cliente['CodCliFC'],
        'patrimonio': locale.format("%.2f", cliente['Patrimonio'], grouping=True, monetary=True),
        'prodotti': [],
        'Bandyer': cliente['Bandyer']
    }

    prodotti = [prodotto['Prodotto'] for prodotto in cliente['PRODOTTI']]
    for prodotto in prodotti:
        anagrafica = prodotto['ANAGRAFICA']
        rapporti = [rapporto['Rapporto'] for rapporto in prodotto['RAPPORTI']]
        output['prodotti'].append(
            {
                'tipo_prodotto': prodotto['TipoProdotto'],
                'anagrafica': {
                    'data_nascita': anagrafica['DTNASCITA'],
                    'nome': anagrafica['Nome'],
                    'cognome': anagrafica['Cognome'],
                    'codice_cliente': anagrafica['CODCLI'],
                    'codice_fiscale': anagrafica['CODFISC'],
                    'tipo_partecipante': anagrafica['TipoPartecipante'],
                    'is_dead': anagrafica['IsDead'],
                    'is_intestatario': anagrafica['IsIntestatario'],
                    'is_cointestatario': anagrafica['IsCointestatario'],
                    'is_found': anagrafica['Found'],
                    'is_persona_fisica': anagrafica['IsPF'],
                    'email': anagrafica['Mail'],
                },
                'rapporti': [{
                    'data_apertura': rapporto['DTAPERTURA'],
                    'codice_rapporto': rapporto['CodiceRapporto'],
                    'classe': rapporto['CLASSE'],
                    'promotore': rapporto['PROMOTORE'],
                    'rete': rapporto['RETE'],
                    'ruolo': rapporto['Ruolo'],
                    'tipo_firma': rapporto['TipoFirma'],
                    'contratti': [{
                        'tipo_piano': contratto['Contratto']['TipoPiano'],
                        'numero_rate_versate': contratto['Contratto']['NumRateVersate'],
                        'numero_contratto': contratto['Contratto']['NumContratto'],
                    } for contratto in rapporto['CONTRATTI']],
                    'squadra': [{
                        'codice_fiscale': squadra['SquadraComponente']['CODFISC'],
                        'ruolo': squadra['SquadraComponente']['Ruolo'],
                        'codice_cliente': squadra['SquadraComponente']['CODCLI'],
                    } for squadra in rapporto['SQUADRA']],
                    'email': rapporto['MAIL'],
                } for rapporto in rapporti]
            }
        )
    output.update({'has_fondi_comuni_intestatario': has_product(output, "FC", 'intestatario')})
    output.update({'has_fondi_comuni_cointestatario': has_product(output, "FC", 'cointestatario')})
    output.update({'has_gestioni_intestatario': has_product(output, "GI", 'intestatario')})
    output.update({'has_gestioni_cointestatario': has_product(output, "GI", 'cointestatario')})
    output.update({'has_consulenze_intestatario': has_product(output, "CO", 'intestatario')})
    output.update({'has_consulenze_cointestatario': has_product(output, "CO", 'cointestatario')})
    output.update({'fondi_rapporti_intestatario': get_product_posizione_rapporti(output, "FC", "intestatario")})
    output.update({'fondi_rapporti_cointestatario': get_product_posizione_rapporti(output, "FC", "cointestatario")})
    output.update({'gestioni_rapporti_intestatario': get_product_posizione_rapporti(output, "GI", "intestatario")})
    output.update({'gestioni_rapporti_cointestatario': get_product_posizione_rapporti(output, "GI", "cointestatario")})
    output.update({'gestioni_contratti_intestatario': get_product_posizione_contratti(output, "GI", "intestatario")})
    output.update({'gestioni_contratti_cointestatario': get_product_posizione_contratti(output, "GI", "cointestatario")})
    return output


def format_ar_riepilogo(riepilogo):
    output = {}
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output['valore_patrimonio'] = locale.format("%.2f", riepilogo['ValATT'], grouping=True, monetary=True)
    output['saldo_sottoscrizioni'] = locale.format("%.2f", riepilogo['SaldoSR'], grouping=True, monetary=True)
    output['rimborsi'] = locale.format("%.2f", riepilogo['SaldoSR_RI'], grouping=True, monetary=True)
    output['sottoscrizioni'] = locale.format("%.2f", riepilogo['SaldoSR_SO'], grouping=True, monetary=True)
    output['utile_perdita'] = locale.format("%.2f", riepilogo['ProfitLoss'], grouping=True, monetary=True)
    output['data_posizione'] = riepilogo['DataPosizione'] if 'DataPosizione' in riepilogo else None
    output['data_nav'] = riepilogo['DataNAV'] if 'DataNAV' in riepilogo else None
    output['codice_cliente'] = riepilogo['Codice_Cliente'] if 'Codice_Cliente' in riepilogo else None
    output['is_negative'] = bool(riepilogo['ProfitLoss'] < 0)
    return output


def format_ar_sintesirapporti(sintesi):
    output = []
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    for array_sr in sintesi:
        sr = array_sr['SintesiRapporti']
        linea = {}
        linea['valori_patrimoniali'] = locale.format("%.2f", sr['ValATT'], grouping=True, monetary=True)
        linea['tipo_partecipazione'] = sr['TipoPartecipazione']
        linea['descrizione_tipo_partecipazione'] = sr['TipoPartecipazioneDescr']
        linea['tipo_prodotto'] = sr['TipoProdotto']
        linea['descrizione_tipo_prodotto'] = sr['TipoProdottoDescr']
        linea['cod_prodotto'] = sr['CodProdotto']
        linea['descrizione_prodotto'] = sr['DescrProdotto']
        linea['quota'] = sr['Quota']
        linea['quote'] = sr['Quote']
        linea['peso'] = sr['Peso']
        linea['classe_prodotto'] = sr['CLASSE']
        linea['saldo'] = locale.format("%.2f", sr['SaldoSR'], grouping=True, monetary=True)
        linea['rimborsi'] = locale.format("%.2f", sr['SaldoSR_RI'], grouping=True, monetary=True)
        linea['sottoscrizioni'] = locale.format("%.2f", sr['SaldoSR_SO'], grouping=True, monetary=True)
        linea['contratto'] = sr['Contratto']
        linea['utili'] = locale.format("%.2f", sr['ProfitLoss'], grouping=True, monetary=True)
        linea['app'] = sr['App']
        linea['rapporto'] = sr['Rapporto']
        linea['is_negative'] = bool(sr['ProfitLoss'] < 0)
        linea['tc'] = sr.get('TC', None)
        output.append(linea)
    return output


def format_ar_depfon(result):
    output = {
        'fondo': result['FONDO'],
        'data1': result['DATA1'],
        'data2': result['DATA2'],
        'title': result['TITLE'],
        'serie': [{
            'data': item['SERIEITEM']['DATA'],
            'val': item['SERIEITEM']['VAL'],
        } for item in result['SERIE']]
    }
    output['highchart'] = highcharts.get_ar_depfon_chart_dataset(output['serie'])
    return output


def format_ar_ripartizione(ripartizione):
    output = []
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    for dettaglio_fondo in [dettaglio['Ripartizione'] for dettaglio in ripartizione]:
        output.append(dict(
            descrizione=dettaglio_fondo['Descrizione'],
            valore=locale.format("%.2f", dettaglio_fondo['ValATT'], grouping=True, monetary=True),
            peso=dettaglio_fondo['Peso'],
            peso_str=locale.format("%.2f", dettaglio_fondo['Peso'], grouping=True, monetary=True),
            rgb=dettaglio_fondo['RGB'],
        ))
    return output


def format_ar_posizione_storica(posizione):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = dict(
        riepilogo=format_ar_riepilogo(posizione),
        sintesi=format_ar_sintesirapporti(posizione['SintesiRapporti']),
        ripartizione=format_ar_ripartizione(posizione['Ripartizione'])
    )
    return output


def format_ar_confronto(confronto):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    sintesi_key = 'ConfrontoSintesiRapporti'
    movimenti_key = 'DepositoMovimento'
    output = {
        'totali': {
            'A': locale.format("%.2f", confronto['TOTALI']['A'], grouping=True, monetary=True),
            'B': locale.format("%.2f", confronto['TOTALI']['B'], grouping=True, monetary=True),
            'C': locale.format("%.2f", confronto['TOTALI']['C'], grouping=True, monetary=True),
            'D': locale.format("%.2f", confronto['TOTALI']['D'], grouping=True, monetary=True),
            'E': locale.format("%.2f", confronto['TOTALI']['E'], grouping=True, monetary=True),
            'rimborsi': locale.format("%.2f", confronto['TOTALI']['B_RI'], grouping=True, monetary=True),
            'sottoscrizioni': locale.format("%.2f", confronto['TOTALI']['B_SO'], grouping=True, monetary=True),
            'is_negative': bool(confronto['TOTALI']['E']<0),
        },
        'sintesi_rapporti': [
            {
                'A': locale.format("%.2f", sintesi[sintesi_key]['A'], grouping=True, monetary=True),
                'B': locale.format("%.2f", sintesi[sintesi_key]['B'], grouping=True, monetary=True),
                'C': locale.format("%.2f", sintesi[sintesi_key]['C'], grouping=True, monetary=True),
                'D': locale.format("%.2f", sintesi[sintesi_key]['D'], grouping=True, monetary=True),
                'E': locale.format("%.2f", sintesi[sintesi_key]['E'], grouping=True, monetary=True),
                'descr_prodotto': sintesi[sintesi_key]['DescrProdotto'],
                'rapporto': sintesi[sintesi_key]['Rapporto'],
                'contratto': sintesi[sintesi_key]['Contratto'],
                'classe_prodotto': sintesi[sintesi_key]['CLASSE'],
                'is_negative': bool(sintesi[sintesi_key]['E']<0),
            } for sintesi in confronto['MERGESINTESIRAPPORTI']
        ],
        'movimenti': [
            {
                'data_registrazione': movimento[movimenti_key]['DataRegistrazione'],
                'cod_cliente': movimento[movimenti_key]['CodCliente'],
                'cod_rapporto': movimento[movimenti_key]['CodRapporto'],
                'cod_deposito': movimento[movimenti_key]['CodDeposito'],
                'descr_fondo': movimento[movimenti_key]['DescrFondo'],
                'causale_descr': movimento[movimenti_key]['CausaleDescr'],
                'progr_caricamento': movimento[movimenti_key]['ProgrCaricamento'],
                'progr_rec_aggancio': movimento[movimenti_key]['ProgrRecAggancio'],
                'val_quota': locale.format("%.3f", movimento[movimenti_key]['ValQuota'], grouping=True, monetary=True),
                'quote': locale.format("%.3f", movimento[movimenti_key]['Quote'], grouping=True, monetary=True),
                'importo_netto': locale.format(
                    "%.2f", movimento[movimenti_key]['ImportoNetto'], grouping=True, monetary=True
                ),
            } for movimento in confronto['MOVIMENTI']
        ]
    }
    return output


def format_ar_movimenti_fc(movimenti):
    output = []
    for operazione in movimenti:
        output.append(operazione['DepositoMovimento'])
    return output


def format_ar_movimenti_gi(movimenti):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = [{
        "data_operazione": movimento['GestioniMovimento']["DTOPERAZIONE"],
        "data_valuta": movimento['GestioniMovimento']["DTVALUTA"],
        "dossier": movimento['GestioniMovimento']["DOSSIER"],
        "linea": movimento['GestioniMovimento']["LINEADESCR"],
        "causale": movimento['GestioniMovimento']["DESCRCAUSALE"],
        "titolo": movimento['GestioniMovimento']["TITOLO"],
        "titolo_isin": movimento['GestioniMovimento']["TITOLOISIN"],
        "tipo_movimento": movimento['GestioniMovimento']["TipoMovimento"],
        'ctv': locale.format("%.2f", movimento['GestioniMovimento']['CTV'], grouping=True, monetary=True),

    } for movimento in movimenti]
    return output


def format_ar_movimento_dett(movimento):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = {
        'tipo_servizio': movimento['TipoServizio'],
        'cod_cliente': movimento['CodCliente'],
        'cod_rapporto': movimento['CodRapporto'],
        'num_contratto': movimento['NumContratto'],
        'tipo_cert_descr': movimento['TipoCertificatoDescr'],
        'data_registrazione': movimento['DataRegistrazione'],
        'data_ricezione': movimento['DataRicezione'],
        'data_valutaMDP': movimento['DataValutaMDP'],
        'data_documento': movimento['DataDocumento'],
        'custodia': movimento['Custodia'],
        'cod_sottocausale': movimento['CodSottocausale'],
        'descr_fondo_switch': movimento['DescrFondoSwitch'],
        'importo_netto': locale.format(
            "%.2f", movimento['ImportoNetto'], grouping=True, monetary=True,
        ),
        'tipo_rapporto': movimento['TipoRapporto'],
        'cod_fondo': movimento['CodFondo'],
        'descr_fondo': movimento['DescrFondo'],
        'causale': movimento['Causale'],
        'descr_causale': movimento['CausaleDescr'],
        'descr_contratto': movimento['TipoContrattoDescr'],
        "valore_quota": locale.format(
            "%.2f", movimento['ValQuota'], grouping=True, monetary=True,
        ),
        'quote': movimento['Quote'],
        'importo_lordo': locale.format(
            "%.2f", movimento['ImportoLordo'], grouping=True, monetary=True,
        ),
        'importo_commissioni': locale.format(
            "%.2f", movimento['ImportoCommissioni'], grouping=True, monetary=True,
        ),
        'importo_spese': locale.format(
            "%.2f", movimento['ImportoSpese'], grouping=True, monetary=True,
        ),
        'tassa_capital_gain': movimento['ImportoRitenuta'],
        'descr_cod_pagamento': movimento['CodPagamentoDescr'],
        'cod_fondo_switch': movimento['CodFondoSwitch'],
    }
    return output


def format_operazioni_in_corso_web(operazioni):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = [{
        "numero_operazione": operazione["OperazioneWEB"]["Nop"] or "",
        "codice_cliente": operazione["OperazioneWEB"]["CodCliente"],
        "codice_rapporto": operazione["OperazioneWEB"]["CodRapp"],
        "codice_deposito": operazione["OperazioneWEB"]["CodDeposito"],
        "descrizione_fondo": operazione["OperazioneWEB"]["DescrFondo"],
        "data": operazione["OperazioneWEB"]["Data"],
        "causale": operazione["OperazioneWEB"]["CausaleDescr"],
        "quote": operazione["OperazioneWEB"]["Quote"],
        "importo": operazione["OperazioneWEB"]["Importo"],
        "fswitch": operazione["OperazioneWEB"]["SwitchDescrFon"] or "",
        "cswitch": operazione["OperazioneWEB"]["SwitchCodDep"] or "",
        "codice_fiscale": operazione["OperazioneWEB"]["CodFisc"],
        "beneficiario_bonifico": operazione["OperazioneWEB"]["BonificoBeneficiario"],
        "IBAN_bonifico": operazione["OperazioneWEB"]["BonificoIBAN"],
        "importo_bonifico": operazione["OperazioneWEB"]["BonificoImporto"],
        "causale_bonifico": operazione["OperazioneWEB"]["BonificoCausale"] or "",
    } for operazione in operazioni]
    return output


def format_operazioni_in_corso_contra(operazioni):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = [{
        "numero_operazione": operazione["DepositoMovimento"]["Nop"] or "",
        "codice_cliente": operazione["DepositoMovimento"]["CodCliente"],
        "codice_rapporto": operazione["DepositoMovimento"]["CodRapporto"],
        "numero_contratto": operazione["DepositoMovimento"]["NumContratto"],
        "descrizione_fondo": operazione["DepositoMovimento"]["DescrFondo"],
        "data": operazione["DepositoMovimento"]["Data"],
        "causale": operazione["DepositoMovimento"]["CausaleDescr"],
        "quote": operazione["DepositoMovimento"]["Quote"],
        "importo": operazione["DepositoMovimento"]["ImportoLordo"],
        "fswitch": operazione["DepositoMovimento"]["DescrFondoSwitch"] or "",
        "beneficiario_bonifico": operazione["DepositoMovimento"]["BonificoBeneficiario"],
        "IBAN_bonifico": operazione["DepositoMovimento"]["BonificoIBAN"],
        "importo_bonifico": operazione["DepositoMovimento"]["BonificoImporto"],
        "causale_bonifico": operazione["DepositoMovimento"]["BonificoCausale"] or "",
    } for operazione in operazioni]
    return output


def format_ar_riclassificazione_gi(riclassificazione, partecipazione):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = []
    for classificazione in riclassificazione:
        item = classificazione['GestioniRiclassificazione']
        app = {
            'nome': item['NOME'],
            'descrizione': item['DESCRIZIONE'],
            'codice': item['CODRICLASSIFICAZIONE'],
            'tabella': [{
                'descrizione': table['ITEM']['DESCR'] or '',
                'valatt': table['ITEM']['VALATT'],
                'formatted_valatt':  locale.format("%.2f", table['ITEM']['VALATT'], grouping=True, monetary=True),
                'peso': table['ITEM']['PESO'],
                'formatted_peso':  locale.format("%.2f", table['ITEM']['PESO']*100, grouping=True, monetary=True),
                'rgb': "#%06x" % random.randint(0, 0xFFFFFF),
            } for table in item['TABELLA']]
        }
        app['highchart'] = highcharts.get_riclassificazione_portafogli_pie_dataset(
            app['tabella'], partecipazione, app['nome']
        )
        output.append(app)
    return output


def format_ar_titoli_gi(titoli):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = []
    for titolo in titoli:
        item = titolo['GestioniTitolo']
        output.append({
            'prezzo': locale.format("%.6f", item['PREZZO'], grouping=True, monetary=True),
            'data_prezzo': item['DTPREZZO'] or '',
            'rateo': locale.format("%.6f", item['RATEO'], grouping=True, monetary=True) if item['RATEO'] else '0',
            'descrizione': item['DESCRIZIONE'],
            'codice_titolo':  item['C_TIT'],
            'valatt': locale.format("%.2f", item['VALATT'], grouping=True, monetary=True),
            'cambio': locale.format("%.6f", item['CAMBIO'], grouping=True, monetary=True),
            'tipo_titolo': item['TIPOTITOLO'],
            'isin': item['ISIN'] or '',
            'peso': locale.format("%.2f", item['PESO']*100, grouping=True, monetary=True),
            'controvalore_rateo': locale.format("%.2f", item['CTVRATEO'], grouping=True, monetary=True),
            'quantita': locale.format("%.3f", item['QTA'], grouping=True, monetary=True),
            'divisa': item['DIVISA'],
            'data_cambio': item['DTCAMBIO'] or '',
            'rapporto': item['RAPPORTO'],
        })
    return output


def format_ar_titolidettprz_gi(dataset):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = {
        'descrizione': dataset['DESCRIZIONE'],
        'isin': dataset['ISIN'],
        'tipo_titolo': dataset['TIPOTITOLO'],
        'divisa': dataset['DIVISA'],
        'macroarea': dataset['MACROAREA'],
        'settore': dataset['SETTORE'],
        'prezzi': [{
            'codice_titolo': prezzo['ITEM']['C_TIT'],
            'prezzo': prezzo['ITEM']['PREZZO'],
            'data': prezzo['ITEM']['DT'],
        } for prezzo in dataset['PREZZI']]
    }
    output['highchart'] = highcharts.get_titolidettprz_gi_chart_dataset(output['prezzi'])
    return output


###################################
def format_servizi_in_corso_web(servizi):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = [{
        'id': servizio['ServiziWEB']["ID"] or "",
        'tipo': servizio['ServiziWEB']["TIPO"],
        'data_operazione': servizio['ServiziWEB']["DATAOPERAZIONE"],
        'rapporto': servizio['ServiziWEB']["RAPPORTO"],
        'numero_contratto': servizio['ServiziWEB']["NUMCONTRATTO"],
        'dati': servizio['ServiziWEB']["DATI"],
        'scadenza': servizio['ServiziWEB']["SCADENZA"],
        'codice_fiscale': servizio['ServiziWEB']["CODFISC"],
    } for servizio in servizi]
    return output


def format_servizi_attivi(servizi):
    try:
        locale.setlocale(locale.LC_ALL, 'it_IT.utf8')
    except Exception, e:
        locale.setlocale(locale.LC_ALL, 'it_IT.UTF-8')
    output = [{
        'id': servizio['ServiziWEB']["ID"] or "",
        'tipo': servizio['ServiziWEB']["TIPO"],
        'data_operazione': servizio['ServiziWEB']["DATAOPERAZIONE"],
        'rapporto': servizio['ServiziWEB']["RAPPORTO"],
        'numero_contratto': servizio['ServiziWEB']["NUMCONTRATTO"],
        'dati': servizio['ServiziWEB']["DATI"],
        'scadenza': servizio['ServiziWEB']["SCADENZA"],
        'revoca': servizio['ServiziWEB']["REVOCA"],
        'codice_fiscale': servizio['ServiziWEB']["CODFISC"],
    } for servizio in servizi]
    return output
